==> eiffelstudio-18.01.10.1424.tar: F_code/C9/gb401.c <==
/*
 * Code for class GB_EV_PICK_AND_DROPABLE_ACTION_SEQUENCES
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "gb401.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GB_EV_PICK_AND_DROPABLE_ACTION_SEQUENCES}.names */
static EIF_REFERENCE F665_6537_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("names", 664, Current, 0, 0, 6855);
	RTGC;
	RTOSP (6537);
#define Result RTOSR(6537)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1373,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9928(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("pick_actions",12,679672691);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(3);
	tr1 = RTMS_EX_H("pick_ended_actions",18,1787005555);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(4);
	tr1 = RTMS_EX_H("conforming_pick_actions",23,1215267955);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(5);
	tr1 = RTMS_EX_H("drop_actions",12,2083555699);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(6);
	F431_5905(RTCW(Result));
	RTOSE (6537);
	RTHOOK(7);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F665_6537 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6537,F665_6537_body,(Current));
}

/* {GB_EV_PICK_AND_DROPABLE_ACTION_SEQUENCES}.types */
static EIF_REFERENCE F665_6538_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("types", 664, Current, 0, 0, 6856);
	RTGC;
	RTOSP (6538);
#define Result RTOSR(6538)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1373,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9928(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("EV_PND_START_ACTION_SEQUENCE",28,32543045);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(3);
	tr1 = RTMS_EX_H("EV_PND_FINISHED_ACTION_SEQUENCE",31,665579589);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(4);
	tr1 = RTMS_EX_H("EV_NOTIFY_ACTION_SEQUENCE",25,1687606853);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(5);
	tr1 = RTMS_EX_H("EV_PND_ACTION_SEQUENCE",22,2104760389);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTOSE (6538);
	RTHOOK(6);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F665_6538 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6538,F665_6538_body,(Current));
}

/* {GB_EV_PICK_AND_DROPABLE_ACTION_SEQUENCES}.comments */
static EIF_REFERENCE F665_6539_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("comments", 664, Current, 0, 0, 6857);
	RTGC;
	RTOSP (6539);
#define Result RTOSR(6539)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1373,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9928(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("-- Actions to be performed when `pebble\' is picked up.",54,1330617390);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(3);
	tr1 = RTMS_EX_H("-- Actions to be performed when a transport from `Current\' ends.",64,1705054510);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(4);
	tr1 = RTMS_EX_H("-- Actions to be performed when a pebble that fits here is picked.",66,1809117230);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(5);
	tr1 = RTMS_EX_H("-- Actions to be performed when a pebble is dropped here.",57,2134405422);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTOSE (6539);
	RTHOOK(6);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F665_6539 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6539,F665_6539_body,(Current));
}

void EIF_Minit401 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C9/gb401.c <==
/*
 * Code for class GB_EV_STANDARD_DIALOG_ACTION_SEQUENCES
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "gb401.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GB_EV_STANDARD_DIALOG_ACTION_SEQUENCES}.names */
static EIF_REFERENCE F665_6542_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("names", 664, Current, 0, 0, 6860);
	RTGC;
	RTOSP (6542);
#define Result RTOSR(6542)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1376,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9931(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("ok_actions",10,146819955);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(3);
	tr1 = RTMS_EX_H("cancel_actions",14,585664627);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(4);
	F431_5905(RTCW(Result));
	RTOSE (6542);
	RTHOOK(5);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F665_6542 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6542,F665_6542_body,(Current));
}

/* {GB_EV_STANDARD_DIALOG_ACTION_SEQUENCES}.types */
static EIF_REFERENCE F665_6543_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("types", 664, Current, 0, 0, 6861);
	RTGC;
	RTOSP (6543);
#define Result RTOSR(6543)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1376,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9931(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("EV_NOTIFY_ACTION_SEQUENCE",25,1687606853);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(3);
	tr1 = RTMS_EX_H("EV_NOTIFY_ACTION_SEQUENCE",25,1687606853);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTOSE (6543);
	RTHOOK(4);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F665_6543 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6543,F665_6543_body,(Current));
}

/* {GB_EV_STANDARD_DIALOG_ACTION_SEQUENCES}.comments */
static EIF_REFERENCE F665_6544_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("comments", 664, Current, 0, 0, 6862);
	RTGC;
	RTOSP (6544);
#define Result RTOSR(6544)
	RTOC_NEW(Result);
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {1080,1376,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 1080, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F1081_9931(RTCW(tr1), ((EIF_INTEGER_32) 0L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS_EX_H("-- Actions to be performed when user clicks OK.",47,1703599406);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTHOOK(3);
	tr1 = RTMS_EX_H("-- Actions to be performed when user cancels.",45,1563854382);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[Dtype(Result)-562])(RTCW(Result), tr1);
	RTOSE (6544);
	RTHOOK(4);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F665_6544 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(6544,F665_6544_body,(Current));
}

void EIF_Minit401 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
